pub struct Manifest {
pub time: u64,
pub files: BTreeMap<String, String>,
}Expand description
A manifest of build artifacts
Fields
time: u64The timestamp of the source control revision
files: BTreeMap<String, String>A dictionary of filenames and their hashes
Implementations
Sourceimpl Manifest
impl Manifest
Sourcepub fn new<P: AsRef<Path>>(time: u64, path: P) -> Result<Manifest>
pub fn new<P: AsRef<Path>>(time: u64, path: P) -> Result<Manifest>
Create a new Manifest by reading the provided build directory
Arguments
time- the timestamp of the source control revision that was builtpath- the directory containing the build artifacts
Return
The Manifest of the provided build data
Errors
Errors that are encountered while reading will be returned